package HTFeed::Namespace::CHI;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'chi';

our $config = {

    # The GRIN ID
    grinid => 'CHI',

    packagetypes => [qw(ht google)],

    description => 'University of Chicago',

    handle_prefix => '2027/chi',

    tags => [qw(bib cic pd_only report)]
};

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;

    # 8 or 9 digits, last digit is check, check digit is sum ( position * value ) mod 10, 
    # position starts at 1

    if($barcode =~ /^\d{8,9}$/) {
        my @digits = split('',$barcode);
        my $check = pop(@digits);
        my $sum = 0;
        for(my $i = 1; $i <= @digits; $i++) {
            $sum += $i * $digits[$i-1];
        }
        my $computed_check = $sum % 10;
        if($computed_check == $check) {
            # matched RE and check digit is good
            return(1);
        }
    }

    # otherwise no good
    return;
}

1;

__END__

=pod

This is the namespace configuration file for University of Chicago

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('chi');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2011 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
