package HTFeed::Namespace::NNC1;
use strict;
use warnings;
use HTFeed::Namespace ;
use List::Util qw(sum);
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'nnc1';

our $config = {

    # The GRIN ID
    grinid => 'Columbia',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/nnc1',
    description => 'Columbia University (Barcoded material)',
    tags => [qw(bib report)]
};

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;

    # A, B: General collections, offsite collections.
    # for A, characters 1-2 are numeric.
    # for B, characters 1-2 are letters
    # digits 3-9 are all numeric
    # digit 10 is check digit

    # validation: 
    #       Let abcdefg stand for digits 3-9
    #       Let x = (8a+7b+6c+5d+4e+3f+2g)
    #       Let y be the remainder when x is divided by 11
    #       Let z be 11-y
    #       If z=10 or 11, set check digit to 0; else, set check digit to value of z

    if($barcode =~ /^([a-z]{2}|\d{2})(\d{7})(\d{1})$/) {
	my $to_check = $2;
	my $existing_checksum = $3;

	my @to_check = split('',$to_check);
	my $checksum = 11 - (sum map { (8-$_) * $to_check[$_] } (0..6)) % 11;
	$checksum = $checksum > 9 ? 0 : $checksum;
	if($checksum == $existing_checksum) {
	    return 1;
	} else {
	    return;
	}
    }
    if($barcode =~ /^50\d{6}$/) {
        # C. Burke Library Collection - 8 digits, all numeric, digits 1-2 = 50. No check scheme.

        return 1;
    } else {
        return;
    }

}

1;

__END__

=pod

This is the namespace configuration file for Columbia University.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('nnc1');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
