package HTFeed::Namespace::UC1;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'uc1';

our $config = {

    # The GRIN ID
    grinid => 'UCAL',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/uc1',
    description => 'University of California (Barcoded material)',
    tags => [qw(bib report)]
};

# Allow filenames prefixed with institution & object ID
our $packagetype_overrides = {
    google => {
	valid_file_pattern => qr/( 
		    checksum\.md5 |
		    ^[\w\$]+\.(xml) |
		    \d{8}.(html|jp2|tif|txt)
		    )/x,
    }

};

sub berkeley_checksum {
    my $self = shift;
    my $barcode = shift;

    my @barcode = split('',$barcode);
    my @factors = (8,6,5,3,2,4,7,9);
    my $sum = 0;

    for(my $i = 0; $i < @factors; $i++) {
        $sum += $barcode[$i] * $factors[$i];
    }

    return ($sum % 10 == $barcode[-1]);
    
}

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;
    # UCB, NRLF - no checksum digit, optional leading $
    # for B1-B999999 (refer to the $BARCODE fiasco)
    return ($barcode =~ /^\$?b\d{1,6}$/ 
    or  ($barcode =~ /^[bc]\d{7}/)
	or  $self->luhn_is_valid('31822',$barcode)  # USCD
	or  $self->luhn_is_valid('31158',$barcode)  # UCLA
	or  $self->luhn_is_valid('32106',$barcode)  # UCSC
	or  $self->luhn_is_valid('31378',$barcode)  # UCSF
    # 11 characters beginning with L, allegedly 'MOD 10' - UCLA
    or  ($barcode =~ /^l(\d{10})/ and Algorithm::LUHN::is_valid($1))
	# or 10 char beginning with C & custom checksum - UCB alternate
    # not yet receiving these
    # or  ($barcode =~ /^c(\d{9})/ and berkeley_checksum($1))
	# or 10 char + 1, 2 or 3 leading A's & complicated checksum - SRLF
    # not yet implemented -- no metadata yet
    # or ($barcode =~ /^a{1,3}\d{9})/ and NOT_YET_IMPLEMENTED($1))
    );
}

1;

__END__

=pod

This is the namespace configuration file for the University of California.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('uc1');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
