package HTFeed::Namespace::UVA;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'uva';

our $config = {

    # The GRIN ID
    grinid => 'UVA',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/uva',
    description => 'University of Virginia',
    tags => [qw(bib report)]
};

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;
    return (
        $barcode =~ /^x\d{9}/ or # University of Virginia Libraries - UPC w/o check digits
        $barcode =~ /^347\d{7}/ or # Virginia - Claude Moore Health Sciences Library
        $self->luhn_is_valid('35007',$barcode)  # Virginia - Law Library
    );
}

1;

__END__

=pod

This is the namespace configuration file for the University of Virginia

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('uva');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
