package HTFeed::Namespace::WU;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'wu';

our $config = {

    # The GRIN ID
    grinid => 'Wisc',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/wu',
    description => 'University of Wisconsin',

    tags => [qw(cic bib report)]
};



sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;

    # 11 digits starting with 89, final digit is check digit
    if($barcode !~ /^89\d{9}$/)  {
	return;
    }

    my $mod;
    my $char;
    my $bar2;
    my $sum = 0;
    my $position = 0;

    $bar2 = substr($barcode, 2, length($barcode)-2);        # split first two digits off
    my @chars = split(//, $bar2);
    my $check = substr($bar2, (length($bar2)-1),1);         # get check digit
    my $drop = pop(@chars);                                 #remove check digit

    foreach $char(@chars) {
	    $position = $position + 1;
	    if ($position % 2) {   #if odd
		    $sum = $sum + $char;
	    } else {
		    if ($char lt 5) {
			    $sum = $sum + ($char * 2)
		    }   else {
			    $sum = $sum + ($char * 2) - 9
		    }
	    }
    }

    if ($sum % 10 == 0) {
	    $mod = 0;
    }   else {
	    $mod = 10 - ($sum % 10);
    }

    if ($check eq $mod) {
	    return 1;
    }   else {
	    return;
    }

}

1;

__END__

=pod

This is the namespace configuration file for the University of Wisconsin.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('wu');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
